<?xml version="1.0"?>
<!-- in case of any change in xsl/xml file modify all connected xsl and xml files from this package  -->

<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" xmlns:graph="graph" xmlns:results="results" extension-element-prefixes="saxon">

    <xsl:include href="res_init.xsl" />
    <xsl:include href="res_build_errors.xsl" />
    <xsl:include href="res_codereview.xsl" />
    <xsl:include href="res_metrics.xsl" />
    <xsl:include href="res_standards.xsl" />
    <xsl:include href="res_generation.xsl" />
    <xsl:include href="res_execution.xsl" />
    <xsl:include href="res_functional.xsl" />
    <xsl:include href="res_api_coverage.xsl" />
    <xsl:include href="res_goals.xsl" />
    <xsl:include href="res_statistics.xsl" />
    
    <!-- ==============  Generate HTML report for manager  ====================  -->               
    <xsl:template match="/">
    <xsl:if test="($report_format_mode='text')">
        <saxon:assign name="nbsp"><xsl:text xml:space="preserve"> </xsl:text></saxon:assign>        
    </xsl:if>
    <xsl:if test="($report_format_mode='pdf')">
        <saxon:assign name="nbsp"><xsl:value-of select="concat('&amp;','#xA0;')"/></saxon:assign>        
        <saxon:assign name="copy"><xsl:value-of select="concat('&amp;','#xA9;')"/></saxon:assign>
    </xsl:if>
 	<saxon:assign name="first_back_to_top">true</saxon:assign>

    <xsl:call-template name="format_time"/>
    <html>
    <head>
    <style type="text/css">
    <xsl:value-of select="($styles)"/>
    </style>    
    <xsl:if test="($report_format_mode='pdf')">
	    <styles_pdf>
		    <xsl:copy-of select="($styles_pdf)"/>    
	    </styles_pdf>
   	</xsl:if>    
    <title>
        <xsl:value-of select="($toolName)"/><xsl:value-of select="($nbsp)" 
             disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_REPORT"/><xsl:value-of select="($nbsp)" 
             disable-output-escaping="yes"/>[<xsl:value-of select="($time)"/>]
    </title>
        
    <xsl:if test="not(($report_type) = ($email_report))">
    <script language="JavaScript">
    <xsl:value-of select="($openWin)"/>
    </script>
    <script language="JavaScript">
    <xsl:value-of select="($sortCodingStandards)"/>
    </script>
    <xsl:if test="($functional) > 0">
        <script language="JavaScript">
           	<xsl:copy-of select="($generateHeader)" />       
            <xsl:value-of select="($showDetailedMessage)"/>
        </script>
        <script language="JavaScript">
        	<xsl:copy-of select="($generateHeader)" />
            <xsl:value-of select="($showTrafficLogWithIterations)" />
        </script>
        <script language="JavaScript">
        	<xsl:copy-of select="($generateHeader)" />
            <xsl:value-of select="($showTrafficLog)"/>
        </script>
        <script language="JavaScript">
        	<xsl:copy-of select="($generateHeader)" />
            <xsl:value-of select="($toggleTestDetails)" />
        </script>
    </xsl:if>
                    
    <script language="JavaScript">
    <xsl:value-of select="($displayTree)"/>
    </script>
    </xsl:if>
    </head>
    <body bgcolor="{$body_color}">             
	<table width='100%' cellpadding='0' cellspacing='0'>
	<xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
	<tr><td>
    <xsl:call-template name="header_image"/>
    
    <table width='100%' style="padding-left:25px;padding-right:25px;padding-bottom:25px;padding-top:0px" cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
    <tr>
    <td align="center">
    <!--saxon:assign name="dev_errors" select="($dev_errors='true') or ($run='gui')"/>
    <xsl:comment>host.name="<xsl:value-of select="($host_name)"/>"</xsl:comment-->
    
    <!-- print header menu -->    
    <xsl:call-template name="menu"/>

	<table width='100%' class="singleborder_blue" style="padding-left:25px;padding-right:25px;padding-bottom:25px;padding-top:5px" cellspacing='0' bgcolor="#FFFFFF" bordercolor="{$blueborder_color}">
	<xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
	<tr><td>
	<xsl:if test="not($send_links_only_mode = $links) or not(($report_type) = ($email_report))">
	<xsl:if test="$report.setup.problems='top'">
    	<xsl:call-template name="display_build_errors"/>
    </xsl:if>
    <xsl:call-template name="display_codereview"/>    
    <xsl:call-template name="display_standards"/>    
    <xsl:call-template name="display_metrics"/>
    <xsl:call-template name="display_apicoverage"/>
    <xsl:call-template name="display_functional">
        <xsl:with-param name="isFunctional">true</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="display_functional">
        <xsl:with-param name="isFunctional">false</xsl:with-param>
    </xsl:call-template>
	<xsl:call-template name="display_generation"/>       
    <xsl:call-template name="display_execution"/>
    <xsl:call-template name="display_goals"/>
    <xsl:call-template name="display_statistics"/>
    <xsl:if test="$report.setup.problems='bottom'">
    	<xsl:call-template name="display_build_errors"/>
    </xsl:if>
    </xsl:if>
    <br/>  
    </td></tr> 
    </table>
    <!-- print footer -->
    <xsl:if test="not($report_type = $email_report)">
    <script language="JavaScript">
    <xsl:value-of select="($init)"/>
    </script>
    </xsl:if>
    </td>
    </tr>
    <!-- xsl:call-template name="footer_image"/>  -->
    </table>
    <xsl:call-template name="footer">
    	<xsl:with-param name="include_params">true</xsl:with-param>
    </xsl:call-template>
    </td></tr></table>
    </body>
    </html>

    <!-- generate HTML reports for developers  -->
    <xsl:if test="($coding_standards) > 0 or ($execution) > 0 or ($generation) > 0 or ($codereview) > 0 or ($functional) or ($change_advisor)">
    <xsl:call-template name="generate_developers_reports"/>
    </xsl:if>
        
    </xsl:template>
    
    <!-- =================  Generate developers reports ============================ -->
    
    <xsl:template name="generate_developers_reports">
        <xsl:for-each select="/ResultsSession/Authors/Author">
        
          <xsl:call-template name="developer_html_report">
             <xsl:with-param name="auth" select="@name"/>
             <xsl:with-param name="authid" select="@id"/>
             <xsl:with-param name="authidx" select="position()"/>
          </xsl:call-template>

       </xsl:for-each>    
    </xsl:template>

    <!-- ========================== Generate HTML report for developer ===================== -->
    
    <xsl:template name="developer_html_report">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    <xsl:param name="authidx"/>
    
 	<saxon:assign name="first_back_to_top">true</saxon:assign>

    <xsl:variable name="author_test_classes" 
        select="count(/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)])"/>
    <xsl:variable name="author_test_cases" 
        select="count(/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)]/TestCaseList/TestCase)"/>
        
    <xsl:variable name="author_cs_errors" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true')])"/>
    <xsl:variable name="author_urgent_cs_errors" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true') and @urgent='true'])"/>
    <xsl:variable name="author_cs_suppr_msgs"
                select="sum(/ResultsSession/CodingStandards/Supps/Supp[@suppAuth=($auth)]/@suppCount)"/>
        
    <xsl:variable name="author_func_errors"
        select="count(/ResultsSession/FunctionalTests/FuncViols/*[@auth=($auth) and not(@supp='true')])"/>
        
    <xsl:variable name="author_change_impacts"
        select="count(/ResultsSession/ChangeAdvisor/ChangeImpacts/*[@auth=($auth) and not(@supp='true')])"/>
        
    <xsl:variable name="author_exec_errors" 
	    select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth)])"/>
    <xsl:variable name="author_exec_urgent_errors" 
        select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth) and @urgent='true'])"/>

	<xsl:variable name="active_user_cr_created_tasks" 
	        select="count(/ResultsSession/CodeReview/ScannerReviews/Review/CreatedTasks/Task[@owner=($auth) and @new='true' and @active='true'])"/>
	<xsl:variable name="active_user_cr_pending_tasks" 
	        select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[@owner=($auth) and (@role='REVIEWER' or @role='OWNER') and @active='true'])"/>
	<xsl:variable name="active_user_cr_monitor_tasks" 
	        select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[@owner=($auth) and @role='QAMANAGER' and @active='true'])"/>
    
    <xsl:variable name="author_html" saxon:assignable="yes" select="concat($output_dir,$dev_reports_prefix,$authid,'.html')"/>

    <!--xsl:if test="($report_type) = ($email_report)">
    <saxon:assign name="author_html" select="concat($output_dir,$auth,'_email','.html')"/>
    </xsl:if>
    <xsl:if test="($report_type) = ($tcm_report)">
    <saxon:assign name="author_html" select="concat($output_dir,$auth,'_tcm','.html')"/>
    </xsl:if-->
    
    <xsl:if test="($dev_reports = 'true')">
    <xsl:if test="($author_cs_errors > 0) or ($author_exec_errors > 0) 
    	or ($active_user_cr_created_tasks > 0) or ($active_user_cr_pending_tasks > 0) or ($active_user_cr_monitor_tasks > 0)
        or (not($author_urgent_cs_errors > 0) and ($suppr_msgs = 'true') and ($author_cs_suppr_msgs) > 0) or ($author_test_cases > 0)
        or ($author_func_errors) > 0 or ($author_change_impacts) > 0">
    <xsl:document href="{$author_html}">
    <html>    
    <head>
        <xsl:if test="($report_format_mode='pdf')">
	    <styles_pdf>
		    <xsl:copy-of select="($styles_pdf)"/>    
	    </styles_pdf>
   		</xsl:if>
    <style type="text/css">
    <xsl:value-of select="($styles)"/>
    </style>
    
    <title>
    <xsl:value-of select="($auth)"/>  
    <xsl:if test="(($author_cs_errors) > 0) or (not($author_urgent_cs_errors > 0) and ($suppr_msgs = 'true') and ($author_cs_suppr_msgs) > 0)">
        - <xsl:value-of select="$RES_PARAMETER_CODING_STANDARDS_LOWERCASE"/> [ <xsl:value-of select="($author_cs_suppr_msgs)"/> / <xsl:value-of select="($author_cs_errors)"/> / <xsl:value-of select="($author_urgent_cs_errors)"/> ]
    </xsl:if>
    <xsl:if test="($author_func_errors) > 0">
        - <xsl:value-of select="$RES_PARAMETER_FUNCTIONAL_TESTS_LOWERCASE"/> [ <xsl:value-of select="($author_func_errors)"/> ] 
    </xsl:if>
    <xsl:if test="($author_change_impacts) > 0">
        - <xsl:value-of select="$RES_PARAMETER_CHANGE_IMPACTS_LOWERCASE"/> [ <xsl:value-of select="($author_change_impacts)"/> ] 
    </xsl:if>
    <xsl:if test="($author_test_classes) > 0">
        - <xsl:value-of select="$RES_PARAMETER_TEST_GENERATION_LOWERCASE"/> [ <xsl:value-of select="($author_test_cases)"/> ]
    </xsl:if>
    <xsl:if test="($author_exec_errors) > 0">
        - <xsl:value-of select="$RES_PARAMETER_TEST_EXECUTION_LOWERCASE"/> [ <xsl:value-of select="($author_exec_errors)"/> / <xsl:value-of select="($author_exec_urgent_errors)"/> ] 
    </xsl:if>
    </title>
    
    <xsl:if test="not(($report_type) = ($email_report))">
       <xsl:if test="($author_cs_errors) > 0">    
          <script language="JavaScript">
             <xsl:value-of select="($openWin)"/>
          </script>    
          <script language="JavaScript">
             <xsl:value-of select="($sortCodingStandards)"/>
          </script>
       </xsl:if>
       <script language="JavaScript">
           <xsl:copy-of select="($generateHeader)" />
           <xsl:value-of select="($showTrafficLogWithIterations)" />
       </script>
       <xsl:if test="($author_func_errors) > 0">
          <script language="JavaScript">
       		 <xsl:copy-of select="($generateHeader)" />
             <xsl:value-of select="($showDetailedMessage)"/>
          </script>
          <script language="JavaScript">
             <xsl:copy-of select="($generateHeader)" />
             <xsl:value-of select="($showTrafficLog)"/>
          </script>
       </xsl:if>
    </xsl:if>   
    </head>

    <body bgcolor="{$body_color}">
    <table width='100%' cellpadding='0' cellspacing='0'>
	<xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
    <tr><td>
    <xsl:call-template name="header_image"/>
	<table width='100%' style="padding-left:25px;padding-right:25px;padding-bottom:25px;padding-top:0px" cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
    <tr>
    <td align="center">
    <table width='100%' border='0' cellpadding='0' cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
    <tr>
    <td align="center">
    <!-- TODO xsl:comment>host.name="<xsl:value-of select="($host_name)"/>"</xsl:comment -->

    <xsl:call-template name="menu">
    	<xsl:with-param name="auth" select="($auth)"/>
    	<xsl:with-param name="authid" select="($authid)"/>
    </xsl:call-template>
    <table width='100%' class="singleborder_blue" style="padding-left:25px;padding-right:25px;padding-bottom:25px;padding-top:5px" cellspacing='0' bgcolor="#FFFFFF" bordercolor="{$blueborder_color}">
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
	<tr><td>
    <xsl:if test="not($send_links_only_mode = $links) or not(($report_type) = ($email_report))">
    <xsl:if test="not($report_format_mode='pdf')">
    <!-- xsl:variable name="individualMenus">
        <xsl:if test="($active_user_cr_created_tasks > 0) or ($active_user_cr_pending_tasks > 0) or ($active_user_cr_monitor_tasks > 0)">
        <td align="center" bgcolor="{$cs_bcolor}">
            <a class="black_link" href="#cr_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_CODEREVIEW"/></b></a>
        </td>
        </xsl:if>
        <xsl:if test="(($author_cs_errors) > 0) or (not($author_urgent_cs_errors > 0) and ($report.suppressed_msgs = 'true') and ($author_cs_suppr_msgs) > 0)">
        <td align="center" bgcolor="{$cs_bcolor}">
            <a class="black_link" href="#cst_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_CODING_STANDARDS"/></b></a>

        </td>
        </xsl:if>
        <xsl:if test="(($author_func_errors) > 0)">
        <td align="center" bgcolor="{$func_bcolor}">
            <a class="black_link" href="#func_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_FUNCTIONAL_TESTS"/></b></a>
        </td>
        </xsl:if>
        <xsl:if test="(($author_change_impacts) > 0)">
        <td align="center" bgcolor="{$func_bcolor}">
            <a class="black_link" href="#change_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_CHANGE_IMPACT"/></b></a>
        </td>
        </xsl:if>
        <xsl:if test="($author_test_classes) > 0">        
        <td align="center" bgcolor="{$exec_bcolor}">
            <a class="black_link" href="#tgt_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_TEST_GENERATION"/></b></a>

        </td>        
        </xsl:if>
        <xsl:if test="($author_exec_errors) > 0">
        <td align="center" bgcolor="{$exec_bcolor}">
            <a class="black_link" href="#tet_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_TEST_EXECUTION"/></b></a>

        </td>
        </xsl:if>
    </xsl:variable -->
    <!-- xsl:if test="count(saxon:node-set($individualMenus)/td) > 1">
    <table width='{$width}' border='1' bordercolor='#999999' cellpadding='0' cellspacing='0'>
        <tr>
        <xsl:if test="string-length($test_config_name) = 0">
            <td width="16%" align="center">
                <font class="time"><xsl:value-of select="($time)"/></font>
            </td>
        </xsl:if>
        <xsl:copy-of select="$individualMenus"/>
        </tr>
    </table>
    <br/>
    </xsl:if -->
    </xsl:if>
    </xsl:if>    
	
	<xsl:if test="not($send_links_only_mode = $links) or not(($report_type) = ($email_report))">
    <!-- code review section -->   
    
    <xsl:if test="($active_user_cr_created_tasks > 0) or ($active_user_cr_pending_tasks > 0) or ($active_user_cr_monitor_tasks > 0)">
    <xsl:call-template name="codereview_header">
    <xsl:with-param name="ref" select="concat('cr_',$auth)"/>  
    </xsl:call-template>
    <br/>
          
    <xsl:call-template name="codereview_author_details_info">
	    <xsl:with-param name="auth" select="($auth)"/>
        <xsl:with-param name="authid" select="($authid)"/>
    </xsl:call-template>
    </xsl:if>       
    
    <!-- coding standards section -->   

    <xsl:if test="(($author_cs_errors) > 0) or (not($author_urgent_cs_errors > 0) and ($suppr_msgs = 'true') and ($author_cs_suppr_msgs) > 0)">
    
    <xsl:call-template name="cs_header">
    <xsl:with-param name="ref" select="concat('cst_',$auth)"/>  
    </xsl:call-template>
    <br/>   
    
    <xsl:call-template name="standards_author_details_info">
        <xsl:with-param name="auth" select="($auth)"/>
        <xsl:with-param name="authid" select="($authid)"/>
        <xsl:with-param name="authidx" select="($authidx)"/>
        <xsl:with-param name="author_cs_errors" select="($author_cs_errors)"/>
        <xsl:with-param name="author_urgent_cs_errors" select="($author_urgent_cs_errors)"/>
        <xsl:with-param name="author_cs_suppr_msgs" select="($author_cs_suppr_msgs)"/>
    </xsl:call-template>
    
    <xsl:if test="($suppr_msgs = 'true') and ($author_cs_suppr_msgs) > 0">
    <xsl:call-template name="supp_messages">
    <xsl:with-param name="auth" select="$auth"/>
    </xsl:call-template>    
        
    </xsl:if>
    </xsl:if>
    
    <!-- functional tests section -->
    <xsl:if test="(($func_errors_nmb) > 0)">
        <xsl:call-template name="func_header">
            <xsl:with-param name="ref" select="concat('func_',$auth)" />
            <xsl:with-param name="isFunctional">true</xsl:with-param>
        </xsl:call-template>

        <br/>
        <table width='{$width}' border='0' bordercolor='{$func_bdrcolor}'
            cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">20% 70% 10%</xsl:attribute>
        </xsl:if>
            <xsl:call-template name="func_summary_details">
                <xsl:with-param name="auth" select="($auth)" />
                <xsl:with-param name="authid" select="($authid)" />
                <xsl:with-param name="isFunctional">true</xsl:with-param>
            </xsl:call-template>
        </table>
    </xsl:if>
    
    <!-- change impacts section -->
    <xsl:if test="(($change_impacts_nmb) > 0)">
        <xsl:call-template name="func_header">
            <xsl:with-param name="ref" select="concat('change_',$auth)" />
            <xsl:with-param name="isFunctional">false</xsl:with-param>
        </xsl:call-template>

        <br/>
        <table width='{$width}' border='0' bordercolor='{$func_bdrcolor}'
            cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">20% 80%</xsl:attribute>
        </xsl:if>
            <xsl:call-template name="func_summary_details">
                <xsl:with-param name="auth" select="($auth)" />
                <xsl:with-param name="authid" select="($authid)" />
                <xsl:with-param name="isFunctional">false</xsl:with-param>
            </xsl:call-template>
        </table>
    </xsl:if>
    
    <!-- test generation section -->       
    <xsl:if test="($author_test_classes) > 0">
    <xsl:if test="($author_exec_errors) > 0 or ($author_cs_errors) > 0">
    <br/>
    </xsl:if>
    <xsl:call-template name="tg_header">
    <xsl:with-param name="ref" select="concat('tgt_',$auth)"/>  
    </xsl:call-template>
    <br/>
    <table width='{$width}' border='0' bordercolor='{$exec_bdrcolor}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">80% 10% 10%</xsl:attribute>
        </xsl:if>
    <xsl:call-template name="tg_author_details_info">
    <xsl:with-param name="auth" select="($auth)"/>
    <xsl:with-param name="mode">single</xsl:with-param>
    </xsl:call-template>
    </table>
    </xsl:if>	

    <!-- test execution section -->   
    
    <xsl:if test="($author_exec_errors) > 0">
    <xsl:if test="($author_cs_errors) > 0">
    <br/>
    </xsl:if>
    <xsl:call-template name="exec_header">
    <xsl:with-param name="ref" select="concat('tet_',$auth)"/>  
    </xsl:call-template>
    <br/>
    <xsl:call-template name="execution_author_details_info">
        <xsl:with-param name="auth" select="($auth)"/>
        <xsl:with-param name="authid" select="($authid)"/>
        <xsl:with-param name="authidx" select="($authidx)"/>
        <xsl:with-param name="author_exec_errors" select="($author_exec_errors)"/>
        <xsl:with-param name="author_exec_urgent_errors" select="($author_exec_urgent_errors)"/>
    </xsl:call-template>
    </xsl:if>    
    </xsl:if>    	
    <!-- print footer -->
    <br/>
        
    <xsl:if test="not($report_type = $email_report)">
    <script language="JavaScript">
    <xsl:value-of select="($init)"/>
    </script>
    </xsl:if>
    </td>
    </tr>
    <!-- xsl:call-template name="footer_image"/> -->
    </table>
    </td></tr>
    </table>
    <xsl:call-template name="footer">
    	<xsl:with-param name="include_params">false</xsl:with-param>
    </xsl:call-template>
    </td>
    </tr>
    </table>
    </td></tr></table>
    </body>
    </html>
    </xsl:document>
    </xsl:if>
    </xsl:if>
    </xsl:template>
        
    <!-- =================  print menu ============================ -->
    
    <xsl:template name="menu">
    <xsl:param name="auth"/>    
    <xsl:param name="authid"/>
    
    <table width="{$width}" border="0" cellpadding="0" cellspacing="0">
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">20% 60% 20%</xsl:attribute>
    </xsl:if>
    <tr>
    <td style="padding-left:20px" align="left" width ="20%">
	    <xsl:if test="not($send_links_only_mode = $links) or not(($report_type) = ($email_report))">
	    <xsl:if test="$report_format_mode='html'">
	    <xsl:variable name="individualMenus">
	    	<xsl:if test="$send_links_only_mode='top'">    	
	        	<tr><xsl:call-template name="display_build_errors_menu"/></tr>
	    	</xsl:if>
	        <!--xsl:call-template name="display_metrics_menu"/-->
	        <tr>
       			<xsl:call-template name="display_codereview_menu">
					<xsl:with-param name="auth" select="$auth"/>
				</xsl:call-template>
	        </tr>
	        <tr>				
       			<xsl:call-template name="display_standards_menu">
       				<xsl:with-param name="auth" select="$auth"/>
       			</xsl:call-template>
	        </tr>
                <tr>
                        <xsl:call-template name="display_apicoverage_menu"/>
                </tr>
	        <tr>            	
        		<xsl:call-template name="display_functional_menu">
	            	<xsl:with-param name="isFunctional">true</xsl:with-param>
       				<xsl:with-param name="auth" select="$auth"/>
				</xsl:call-template>       			
	        </tr>
	        <tr>
	        	<xsl:call-template name="display_functional_menu">
	            	<xsl:with-param name="isFunctional">false</xsl:with-param>
        			<xsl:with-param name="auth" select="$auth"/>
	        	</xsl:call-template>
        	</tr>
			<tr>
				<xsl:call-template name="display_generation_menu">
        			<xsl:with-param name="auth" select="$auth"/>
				</xsl:call-template>
			</tr>        
	        <tr>
	       		<xsl:call-template name="display_execution_menu">
	       			<xsl:with-param name="auth" select="$auth"/>
	       		</xsl:call-template>
	        </tr>
	        <xsl:if test="not($authid)">
		        <tr><xsl:call-template name="display_goals_menu"/></tr>
		        <tr><xsl:call-template name="display_statistics_menu"/></tr>
	        </xsl:if>
	        
	        <xsl:if test="$report.setup.problems='bottom'">    	    
	        	<tr><xsl:call-template name="display_build_errors_menu"/></tr>
	    	</xsl:if>
	    </xsl:variable>
	    <xsl:if test="count(saxon:node-set($individualMenus)/tr/td) > 1">
	    <table width="{$width}" border="0" cellpadding="0" cellspacing="0">
	        <xsl:if test="($report_format_mode='pdf')">
	            <xsl:attribute name="cols">30% 70%</xsl:attribute>
	        </xsl:if>               
	        <xsl:copy-of select="$individualMenus/tr[count(./td) > 0]"/>
        </table>
	    </xsl:if>
	    </xsl:if>
	    </xsl:if>
    </td>
    <td style="padding:10px" align="center" width ="60%">
	    <table align="center" width="{$width}" border="0" cellpadding="0" cellspacing="0">
	        <xsl:if test="($report_format_mode='pdf')">
	            <xsl:attribute name="cols">100%</xsl:attribute>
	        </xsl:if>
	    <xsl:if test="string-length($test_config_name) > 0">
	    <tr>    
	    	<td align="center">             	
	    		<xsl:if test="string-length($test_config_origin) > 0">
	    			<xsl:value-of select="$test_config_origin"/>:
	    		</xsl:if>
	    		<xsl:if test="string-length($test_config_origin) = 0">
	    			<xsl:value-of select="$RES_PARAMETER_RESULTS_FROM"/>
	    		</xsl:if>
	         	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
	          	<b><xsl:value-of select="$test_config_name"/></b>                           
	    	</td>       
	    </tr>
	    </xsl:if>
	    <tr>
	    	<td width="16%" align="center">
		        <font class="time"><xsl:value-of select="($time)"/></font>
		    </td>
	    </tr>
	    </table>
    </td>
    <td style="padding-right:20px" align="right" width ="20%">
    </td>
    </tr>

    </table>    
    </xsl:template>
    
    <!-- =================  print footer ============================ -->
    
    <xsl:template name="footer">
    <xsl:param name="include_params"/>
        
    <xsl:if test="$include_params='true' and (string-length($test_params) > 0)">

    <table style="padding-right:25px;padding-left:25px"  width='100%' cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
    <tr>
    <td>
            <table width="{$width}" class="singleborder_blue" bgcolor="#FFFFFF" bordercolor='{$blueborder_color}' cellspacing="0" align="center" rules="none">
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">100%</xsl:attribute>
                </xsl:if>
                <tr>
                    <td bgcolor="#FFFFFF" align="center">
                        <div class="small_header">Test Parameters</div> 
                    </td>
                </tr>
                <tr>
                    <td style="padding-right:25px;padding-left:25px;padding-top:4px;padding-bottom:4px" bgcolor="#FFFFFF" align="left">
                    	<table class="doubleborder" width="100%" bordercolor="{$berr_bdrcolor}" cellpadding="4" cellspacing="0" align="center">
                    	<xsl:if test="($report_format_mode='pdf')">
		                    <xsl:attribute name="cols">100%</xsl:attribute>
		                </xsl:if>
                    	<tr>
                    		<td bgcolor="#FFFFFF" align="left">
                    			<div id="paramsHeader"><xsl:value-of select="$test_params"/></div>
                    		</td>
                		</tr>
            			</table>
                    </td>
                </tr>
            </table>
    </td>
    </tr>
    </table>
            <br /> 
        </xsl:if>
        
    <table width='100%' bgcolor="{$footer_color}" border='0' bordercolor='#999999' cellpadding='10' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr>
    <td align="center"> 
    <font class="white">
    <xsl:value-of select="($copy)" disable-output-escaping="yes"/>
        <xsl:value-of select="$RES_PARAMETER_PARASOFT"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($toolName)"/><!--xsl:value-of select="($copy)" disable-output-escaping="yes"/-->
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($toolVer)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <xsl:value-of select="$RES_PARAMETER_REPORTIMNG_SYSTEM"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:if test="string-length($os_name) > 0">   
        <xsl:value-of select="$RES_PARAMETER_OS"/> <xsl:value-of select="($os_name)"/>
    </xsl:if>   
    </font> 
    </td>
    </tr>
    </table>
    </xsl:template> 

    <!-- ==============  import_errs  ====================  -->
    
    <xsl:template name="import_errs">
        <xsl:value-of select="$RES_PARAMETER_PUSH_BUTTON_INFO"/> 
    </xsl:template>
    
</xsl:stylesheet>
